@@ -1,13 +1,5 @@
-# -*- coding: utf-8 -*-
-"""
-Created on Tue Feb  2 19:58:48 2021
-
-@author: -
-https://www.postgresqltutorial.com/postgresql-python/connect/
-"""
-
-# from mysql.connector
-import mysql.connector as misql
+# import mysql.connector as misql
+import mysql.connector
 import traceback
 import sys
 import csv
@@ -22,7 +14,7 @@ class DbConnection:
         self.data_base_type = db_type
         try:
             params = config(filename=self.iniFile, section=db_type)
-            self.connection = misql.connect(**params)
+            self.connection = mysql.connector.connect(**params)
         except Exception as err:
             print(err)
 
@@ -67,7 +59,7 @@ class DbConnection:
             query = 'CREATE SCHEMA {}'.format(schema_name)
             cursor.execute(query)
             cursor.close()
-        except misql.Error as err:
+        except mysql.connector.Error as err:
             print('mysql.Error', err.msg)
         except Exception:
             print(traceback.format_exc())
